searchData={"items":[{"type":"behaviour","title":"SupervisedServer","doc":"A behaviour module for starting supervised GenServer processes.\n\nWith the use of `SupervisedServer`, you can avoid the need to add `c:start_link/1` function\nto your module every time you write a new one.\nAnd if you need your own `c:start_link/1` function, you can override it.","ref":"SupervisedServer.html"},{"type":"behaviour","title":"Usage - SupervisedServer","doc":"* Add `use SupervisedServer` to your module.\n* View [`Examples`](#module-examples).\n\n> #### `use SupervisedServer` {: .info}\n>\n> When you `use SupervisedServer`, the SupervisedServer module will:\n> * set `@behaviour SupervisedServer`,\n> * add `use GenServer`,\n> * pass options passed to `use SupervisedServer` to `use GenServer`,\n> * define a `c:start_link/1` function, so your module does not need to define it\n> if you don't want a custom one.","ref":"SupervisedServer.html#module-usage"},{"type":"behaviour","title":"Callbacks - SupervisedServer","doc":"The following callbacks may be implemented by modules that use the `SupervisedServer` behavior:\n\n- `c:start_link/1`: Starts a GenServer process linked to the current process.\n  This function is often used to start the server as part of a supervision tree.\n\n`c:start_link/1` callback should return one of the following values:\n\n- `{:ok, pid}`: The server was successfully created and initialized.\n\n- `:ignore`: The server should be ignored, and no further action is taken.\n\n- `{:error, {:already_started, pid}}`: A process with the specified name already exists.\n\n- `{:error, reason}`: The initialization of the server failed for the given reason.\n\n- `{:stop, reason}`: The process is terminated due to the provided reason.","ref":"SupervisedServer.html#module-callbacks"},{"type":"behaviour","title":"Options - SupervisedServer","doc":"`c:start_link/1` callback accept the following option:\n\n- `:name` (optional): Used for name registration as described in the \"Name Registration\" section\n  in the documentation for `GenServer`.","ref":"SupervisedServer.html#module-options"},{"type":"behaviour","title":"Examples - SupervisedServer","doc":"#","ref":"SupervisedServer.html#module-examples"},{"type":"behaviour","title":"Basic usage - SupervisedServer","doc":"```elixir\niex> defmodule MyServer do\n...>  use SupervisedServer\n...>\n...>  @impl GenServer\n...>  def init(arg) do\n...>    {:ok, arg}\n...>  end\n...>end\n...># Starting a supervised process\n...>{:ok, _} = Supervisor.start_link([MyServer], strategy: :one_for_one)\n```\n\n#","ref":"SupervisedServer.html#module-basic-usage"},{"type":"behaviour","title":"Additional options - SupervisedServer","doc":"```elixir\niex> defmodule TransientServer do\n...>  use SupervisedServer, restart: :transient, shutdown: 10_000\n...>\n...>  @impl GenServer\n...>  def init(arg) do\n...>    {:ok, arg}\n...>  end\n...>end\n...># Starting a supervised process\n...>{:ok, sup} = Supervisor.start_link([TransientServer], strategy: :one_for_one)\n...>{:ok, chldspec} = :supervisor.get_childspec(sup, TransientServer)\n...>assert chldspec.restart == :transient\n...>assert chldspec.shutdown == 10_000\n```\n\n#","ref":"SupervisedServer.html#module-additional-options"},{"type":"behaviour","title":"Naming the process - SupervisedServer","doc":"```elixir\niex>defmodule NamedServer do\n...>  use SupervisedServer\n...>\n...>  @impl GenServer\n...>  def init(arg) do\n...>    {:ok, arg}\n...>  end\n...>\n...>  @impl GenServer\n...>  def handle_call(:get_my_arg, _from, state) do\n...>    {:reply, {:ok, state[:my_arg]}, state}\n...>  end\n...>\n...>  def get_my_arg(pid) do\n...>    GenServer.call(pid, :get_my_arg)\n...>  end\n...>end\n...>\n...>children = [\n...>  {NamedServer, [my_arg: \"Hello named server!\", name: :my_named_server]}\n...>]\n...># Starting a named supervised process\n...>{:ok, _} = Supervisor.start_link(children, strategy: :one_for_one)\n...>\n...># Access the named process using its registered name\n...>{:ok, \"Hello named server!\"} = NamedServer.get_my_arg(:my_named_server)\n```\n\n#","ref":"SupervisedServer.html#module-naming-the-process"},{"type":"behaviour","title":"Custom start_link/1 - SupervisedServer","doc":"```elixir\niex>defmodule CustomServer do\n...>  use SupervisedServer\n...>\n...>  # Override start_link/1 to provide additional options\n...>  @impl SupervisedServer\n...>  def start_link(args) when is_list(args) do\n...>    GenServer.start_link(__MODULE__, args, name: :custom_server)\n...>  end\n...>\n...>  @impl GenServer\n...>  def init(arg) do\n...>    {:ok, arg}\n...>  end\n...>end\n...>\n...># Starting a custom supervised GenServer process\n...>{:ok, _} = Supervisor.start_link([CustomServer], strategy: :one_for_one)\n...>pid = Process.whereis(:custom_server)\n...>true = is_pid(pid)\n```","ref":"SupervisedServer.html#module-custom-start_link-1"},{"type":"behaviour","title":"References - SupervisedServer","doc":"* `GenServer`\n* `Supervisor`","ref":"SupervisedServer.html#module-references"},{"type":"callback","title":"SupervisedServer.start_link/1","doc":"Starts a `SupervisedServer` process linked to the current process.\n\nThis is often used to start the `SupervisedServer` as part of a supervision tree.\n\nOnce the server is started, the `init/1` function of the given is called\nwith `init_arg` as its argument to initialize the server. To ensure a\nsynchronized start-up procedure, this function does not return until `init/1`\nhas returned.\n\nNote that a `SupervisedServer` started with `c:start_link/1` is linked to the\nparent process and will exit in case of crashes from the parent. The `SupervisedServer`\nwill also exit due to the `:normal` reasons in case it is configured to trap\nexits in the `init/1` callback.","ref":"SupervisedServer.html#c:start_link/1"},{"type":"callback","title":"Options - SupervisedServer.start_link/1","doc":"- `:name` (optional): Used for name registration as described in the \"Name Registration\" section\n  in the documentation for `GenServer`.","ref":"SupervisedServer.html#c:start_link/1-options"},{"type":"callback","title":"Return values - SupervisedServer.start_link/1","doc":"If the server is successfully created and initialized, this function returns\n`{:ok, pid}`, where `pid` is the PID of the server. If a process with the\nspecified server name already exists, this function returns\n`{:error, {:already_started, pid}}` with the PID of that process.\n\nIf the `init/1` callback fails with `reason`, this function returns\n`{:error, reason}`. Otherwise, if it returns `{:stop, reason}`\nor `:ignore`, the process is terminated and this function returns\n`{:error, reason}` or `:ignore`, respectively.","ref":"SupervisedServer.html#c:start_link/1-return-values"}],"content_type":"text/markdown"}